@@ -43,17 +43,17 @@ _invoke_callable (PyGIInvokeState *state,
         retval = g_vfunc_info_invoke ( callable_info,
                                        state->implementor_gtype,
                                        state->in_args,
-                                       cache->n_in_args,
+                                       cache->n_from_py_args,
                                        state->out_args,
-                                       cache->n_out_args,
+                                       cache->n_to_py_args,
                                       &state->return_arg,
                                       &error);
     else
         retval = g_function_info_invoke ( callable_info,
                                           state->in_args,
-                                          cache->n_in_args,
+                                          cache->n_from_py_args,
                                           state->out_args,
-                                          cache->n_out_args,
+                                          cache->n_to_py_args,
                                          &state->return_arg,
                                          &error);
     pyg_end_allow_threads;
@@ -67,7 +67,7 @@ _invoke_callable (PyGIInvokeState *state,
          * We eventually should marshal directly to FFI so we no longer
          * have to use the reference implementation
          */
-        pygi_marshal_cleanup_args_in_marshal_success (state, cache);
+        pygi_marshal_cleanup_args_from_py_marshal_success (state, cache);
 
         return FALSE;
     }
@@ -76,7 +76,7 @@ _invoke_callable (PyGIInvokeState *state,
         if (pyglib_error_check (&(state->error))) {
             /* even though we errored out, the call itself was successful,
                so we assume the call processed all of the parameters */
-            pygi_marshal_cleanup_args_in_marshal_success (state, cache);
+            pygi_marshal_cleanup_args_from_py_marshal_success (state, cache);
             return FALSE;
         }
     }
@@ -299,20 +299,20 @@ _invoke_state_init_from_callable_cache (PyGIInvokeState *state,
         return FALSE;
     }
 
-    state->in_args = g_slice_alloc0 (cache->n_in_args * sizeof(GIArgument));
-    if (state->in_args == NULL && cache->n_in_args != 0) {
+    state->in_args = g_slice_alloc0 (cache->n_from_py_args * sizeof(GIArgument));
+    if (state->in_args == NULL && cache->n_from_py_args != 0) {
         PyErr_NoMemory ();
         return FALSE;
     }
 
-    state->out_values = g_slice_alloc0 (cache->n_out_args * sizeof(GIArgument));
-    if (state->out_values == NULL && cache->n_out_args != 0) {
+    state->out_values = g_slice_alloc0 (cache->n_to_py_args * sizeof(GIArgument));
+    if (state->out_values == NULL && cache->n_to_py_args != 0) {
         PyErr_NoMemory ();
         return FALSE;
     }
 
-    state->out_args = g_slice_alloc0 (cache->n_out_args * sizeof(GIArgument));
-    if (state->out_args == NULL && cache->n_out_args != 0) {
+    state->out_args = g_slice_alloc0 (cache->n_to_py_args * sizeof(GIArgument));
+    if (state->out_args == NULL && cache->n_to_py_args != 0) {
         PyErr_NoMemory ();
         return FALSE;
     }
@@ -326,9 +326,9 @@ static inline void
 _invoke_state_clear (PyGIInvokeState *state, PyGICallableCache *cache)
 {
     g_slice_free1 (cache->n_args * sizeof(GIArgument *), state->args);
-    g_slice_free1 (cache->n_in_args * sizeof(GIArgument), state->in_args);
-    g_slice_free1 (cache->n_out_args * sizeof(GIArgument), state->out_args);
-    g_slice_free1 (cache->n_out_args * sizeof(GIArgument), state->out_values);
+    g_slice_free1 (cache->n_from_py_args * sizeof(GIArgument), state->in_args);
+    g_slice_free1 (cache->n_to_py_args * sizeof(GIArgument), state->out_args);
+    g_slice_free1 (cache->n_to_py_args * sizeof(GIArgument), state->out_values);
 
     Py_XDECREF (state->py_in_args);
 }
@@ -396,7 +396,7 @@ _invoke_marshal_in_args (PyGIInvokeState *state, PyGICallableCache *cache)
         PyObject *py_arg = NULL;
 
         switch (arg_cache->direction) {
-            case GI_DIRECTION_IN:
+            case PYGI_DIRECTION_FROM_PYTHON:
                 state->args[i] = &(state->in_args[in_count]);
                 in_count++;
 
@@ -413,9 +413,9 @@ _invoke_marshal_in_args (PyGIInvokeState *state, PyGICallableCache *cache)
                     /* clean up all of the args we have already marshalled,
                      * since invoke will not be called
                      */
-                    pygi_marshal_cleanup_args_in_parameter_fail (state,
-                                                                 cache,
-                                                                 i - 1);
+                    pygi_marshal_cleanup_args_from_py_parameter_fail (state,
+                                                                      cache,
+                                                                      i - 1);
                     return FALSE;
                 }
 
@@ -424,7 +424,7 @@ _invoke_marshal_in_args (PyGIInvokeState *state, PyGICallableCache *cache)
                                       arg_cache->py_arg_index);
 
                 break;
-            case GI_DIRECTION_INOUT:
+            case PYGI_DIRECTION_BIDIRECTIONAL:
                 /* this will be filled in if it is an child value */
                 if (state->in_args[in_count].v_pointer != NULL)
                     state->out_values[out_count] = state->in_args[in_count];
@@ -439,9 +439,9 @@ _invoke_marshal_in_args (PyGIInvokeState *state, PyGICallableCache *cache)
                                        cache->name,
                                        cache->n_py_args,
                                        state->n_py_in_args);
-                        pygi_marshal_cleanup_args_in_parameter_fail (state,
-                                                                     cache,
-                                                                     i - 1);
+                        pygi_marshal_cleanup_args_from_py_parameter_fail (state,
+                                                                          cache,
+                                                                          i - 1);
                         return FALSE;
                     }
 
@@ -449,15 +449,15 @@ _invoke_marshal_in_args (PyGIInvokeState *state, PyGICallableCache *cache)
                         PyTuple_GET_ITEM (state->py_in_args,
                                           arg_cache->py_arg_index);
                 }
-            case GI_DIRECTION_OUT:
+            case PYGI_DIRECTION_TO_PYTHON:
                 if (arg_cache->is_caller_allocates) {
                     if (!_caller_alloc (state, arg_cache, i, out_count)) {
                         PyErr_Format (PyExc_TypeError,
                                       "Could not caller allocate argument %zd of callable %s",
                                       i, cache->name);
-                        pygi_marshal_cleanup_args_in_parameter_fail (state,
-                                                                     cache,
-                                                                     i - 1);
+                        pygi_marshal_cleanup_args_from_py_parameter_fail (state,
+                                                                          cache,
+                                                                          i - 1);
                         return FALSE;
                     }
                 } else {
@@ -469,26 +469,26 @@ _invoke_marshal_in_args (PyGIInvokeState *state, PyGICallableCache *cache)
         }
 
         c_arg = state->args[i];
-        if (arg_cache->in_marshaller != NULL) {
+        if (arg_cache->from_py_marshaller != NULL) {
             if (!arg_cache->allow_none && py_arg == Py_None) {
                 PyErr_Format (PyExc_TypeError,
-                              "Argument %i does not allow None as a value",
+                              "Argument %zd does not allow None as a value",
                               i);
 
-                 pygi_marshal_cleanup_args_in_parameter_fail (state,
-                                                              cache,
-                                                              i - 1);
+                 pygi_marshal_cleanup_args_from_py_parameter_fail (state,
+                                                                   cache,
+                                                                   i - 1);
                  return FALSE;
             }
-            gboolean success = arg_cache->in_marshaller (state,
-                                                         cache,
-                                                         arg_cache,
-                                                         py_arg,
-                                                         c_arg);
-            if (!success) {
-                pygi_marshal_cleanup_args_in_parameter_fail (state,
+            gboolean success = arg_cache->from_py_marshaller (state,
                                                               cache,
-                                                              i - 1);
+                                                              arg_cache,
+                                                              py_arg,
+                                                              c_arg);
+            if (!success) {
+                pygi_marshal_cleanup_args_from_py_parameter_fail (state,
+                                                                  cache,
+                                                                  i - 1);
                 return FALSE;
             }
 
@@ -504,7 +504,7 @@ _invoke_marshal_out_args (PyGIInvokeState *state, PyGICallableCache *cache)
 {
     PyObject *py_out = NULL;
     PyObject *py_return = NULL;
-    gssize total_out_args = cache->n_out_args;
+    gssize total_out_args = cache->n_to_py_args;
     gboolean has_return = FALSE;
 
     if (cache->return_cache) {
@@ -518,10 +518,10 @@ _invoke_marshal_out_args (PyGIInvokeState *state, PyGICallableCache *cache)
                 }
             }
 
-            py_return = cache->return_cache->out_marshaller ( state,
-                                                              cache,
-                                                              cache->return_cache,
-                                                             &state->return_arg);
+            py_return = cache->return_cache->to_py_marshaller ( state,
+                                                                cache,
+                                                                cache->return_cache,
+                                                               &state->return_arg);
             if (py_return == NULL) {
                 pygi_marshal_cleanup_args_return_fail (state,
                                                        cache);
@@ -535,39 +535,39 @@ _invoke_marshal_out_args (PyGIInvokeState *state, PyGICallableCache *cache)
             }
         } else {
             if (cache->return_cache->transfer == GI_TRANSFER_EVERYTHING) {
-                PyGIMarshalCleanupFunc out_cleanup =
-                    cache->return_cache->out_cleanup;
+                PyGIMarshalCleanupFunc to_py_cleanup =
+                    cache->return_cache->to_py_cleanup;
 
-                if (out_cleanup != NULL)
-                    out_cleanup ( state,
-                                  cache->return_cache,
-                                 &state->return_arg,
-                                  FALSE);
+                if (to_py_cleanup != NULL)
+                    to_py_cleanup ( state,
+                                    cache->return_cache,
+                                   &state->return_arg,
+                                    FALSE);
             }
         }
     }
 
-    total_out_args -= cache->n_out_child_args;
+    total_out_args -= cache->n_to_py_child_args;
 
-    if (cache->n_out_args - cache->n_out_child_args  == 0) {
+    if (cache->n_to_py_args - cache->n_to_py_child_args  == 0) {
         py_out = py_return;
     } else if (total_out_args == 1) {
         /* if we get here there is one out arg an no return */
-        PyGIArgCache *arg_cache = (PyGIArgCache *)cache->out_args->data;
-        py_out = arg_cache->out_marshaller (state,
-                                            cache,
-                                            arg_cache,
-                                            state->args[arg_cache->c_arg_index]);
+        PyGIArgCache *arg_cache = (PyGIArgCache *)cache->to_py_args->data;
+        py_out = arg_cache->to_py_marshaller (state,
+                                              cache,
+                                              arg_cache,
+                                              state->args[arg_cache->c_arg_index]);
         if (py_out == NULL) {
-            pygi_marshal_cleanup_args_out_parameter_fail (state,
-                                                          cache,
-                                                          0);
+            pygi_marshal_cleanup_args_to_py_parameter_fail (state,
+                                                            cache,
+                                                            0);
             return NULL;
         }
 
     } else {
         gssize py_arg_index = 0;
-        GSList *cache_item = cache->out_args;
+        GSList *cache_item = cache->to_py_args;
         /* return a tuple */
         py_out = PyTuple_New (total_out_args);
         if (has_return) {
@@ -577,18 +577,18 @@ _invoke_marshal_out_args (PyGIInvokeState *state, PyGICallableCache *cache)
 
         for(; py_arg_index < total_out_args; py_arg_index++) {
             PyGIArgCache *arg_cache = (PyGIArgCache *)cache_item->data;
-            PyObject *py_obj = arg_cache->out_marshaller (state,
-                                                          cache,
-                                                          arg_cache,
-                                                          state->args[arg_cache->c_arg_index]);
+            PyObject *py_obj = arg_cache->to_py_marshaller (state,
+                                                            cache,
+                                                            arg_cache,
+                                                            state->args[arg_cache->c_arg_index]);
 
             if (py_obj == NULL) {
                 if (has_return)
                     py_arg_index--;
  
-                pygi_marshal_cleanup_args_out_parameter_fail (state,
-                                                              cache,
-                                                              py_arg_index);
+                pygi_marshal_cleanup_args_to_py_parameter_fail (state,
+                                                                cache,
+                                                                py_arg_index);
                 Py_DECREF (py_out);
                 return NULL;
             }
@@ -623,11 +623,11 @@ _wrap_g_callable_info_invoke (PyGIBaseInfo *self,
     if (!_invoke_callable (&state, self->cache, self->info))
         goto err;
 
-    pygi_marshal_cleanup_args_in_marshal_success (&state, self->cache);
+    pygi_marshal_cleanup_args_from_py_marshal_success (&state, self->cache);
 
     ret = _invoke_marshal_out_args (&state, self->cache);
     if (ret)
-        pygi_marshal_cleanup_args_out_marshal_success (&state, self->cache);
+        pygi_marshal_cleanup_args_to_py_marshal_success (&state, self->cache);
 err:
     _invoke_state_clear (&state, self->cache);
     return ret;
